joker_dio library
Classes
- Joker
- JokerDioInterceptor
- A Dio interceptor that intercepts requests and returns stubbed responses when Joker is active and has matching stubs.
- JokerResponse
- Response data that will be returned for a matched request
- JokerStub
- A stub that defines how to respond to a matched HTTP request
Extensions
- JokerFileOperations on Joker
- Extension methods for Joker that require dart:io
- JokerResponseFile on JokerResponse
- Extension methods for JokerResponse that require dart:io